using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for AlphabeticalListOfProducts.  Do not make changes to this class,
     /// instead, put additional code in the AlphabeticalListOfProducts class
     /// </summary>
     public class AlphabeticalListOfProductsBase
     {
         /// <summary>
         /// Gets or Sets ProductID
         /// </summary>
         public int ProductID { get; set; }

         /// <summary>
         /// Gets or Sets ProductName
         /// </summary>
         public string ProductName { get; set; }

         /// <summary>
         /// Gets or Sets SupplierID
         /// </summary>
         public int? SupplierID { get; set; }

         /// <summary>
         /// Gets or Sets CategoryID
         /// </summary>
         public int? CategoryID { get; set; }

         /// <summary>
         /// Gets or Sets QuantityPerUnit
         /// </summary>
         public string QuantityPerUnit { get; set; }

         /// <summary>
         /// Gets or Sets UnitPrice
         /// </summary>
         public decimal? UnitPrice { get; set; }

         /// <summary>
         /// Gets or Sets UnitPriceTotal
         /// </summary>
         public decimal UnitPriceTotal { get; set; }

         /// <summary>
         /// Gets or Sets UnitsInStock
         /// </summary>
         public Int16? UnitsInStock { get; set; }

         /// <summary>
         /// Gets or Sets UnitsOnOrder
         /// </summary>
         public Int16? UnitsOnOrder { get; set; }

         /// <summary>
         /// Gets or Sets ReorderLevel
         /// </summary>
         public Int16? ReorderLevel { get; set; }

         /// <summary>
         /// Gets or Sets Discontinued
         /// </summary>
         public bool Discontinued { get; set; }

         /// <summary>
         /// Gets or Sets CategoryName
         /// </summary>
         public string CategoryName { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public AlphabeticalListOfProductsBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the AlphabeticalListOfProducts table
         /// </summary>
         public static int GetRecordCount()
         {
             return AlphabeticalListOfProductsDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of AlphabeticalListOfProducts sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static AlphabeticalListOfProductsCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return AlphabeticalListOfProductsDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of AlphabeticalListOfProducts sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static AlphabeticalListOfProductsCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return AlphabeticalListOfProductsDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "ProductID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares ProductID used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByProductID = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return x.ProductID.CompareTo(y.ProductID);
         };

         /// <summary>
         /// Compares ProductName used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByProductName = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             string value1 = x.ProductName ?? String.Empty;
             string value2 = y.ProductName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares SupplierID used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> BySupplierID = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return Nullable.Compare(x.SupplierID, y.SupplierID);
         };

         /// <summary>
         /// Compares CategoryID used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByCategoryID = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return Nullable.Compare(x.CategoryID, y.CategoryID);
         };

         /// <summary>
         /// Compares QuantityPerUnit used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByQuantityPerUnit = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             string value1 = x.QuantityPerUnit ?? String.Empty;
             string value2 = y.QuantityPerUnit ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares UnitPrice used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByUnitPrice = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return Nullable.Compare(x.UnitPrice, y.UnitPrice);
         };

         /// <summary>
         /// Compares UnitsInStock used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByUnitsInStock = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return Nullable.Compare(x.UnitsInStock, y.UnitsInStock);
         };

         /// <summary>
         /// Compares UnitsOnOrder used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByUnitsOnOrder = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return Nullable.Compare(x.UnitsOnOrder, y.UnitsOnOrder);
         };

         /// <summary>
         /// Compares ReorderLevel used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByReorderLevel = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return Nullable.Compare(x.ReorderLevel, y.ReorderLevel);
         };

         /// <summary>
         /// Compares Discontinued used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByDiscontinued = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             return x.Discontinued.CompareTo(y.Discontinued);
         };

         /// <summary>
         /// Compares CategoryName used for sorting
         /// </summary>
         public static Comparison<AlphabeticalListOfProducts> ByCategoryName = delegate(AlphabeticalListOfProducts x, AlphabeticalListOfProducts y)
         {
             string value1 = x.CategoryName ?? String.Empty;
             string value2 = y.CategoryName ?? String.Empty;
             return value1.CompareTo(value2);
         };

     }
}
