using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for CurrentProductList.  Do not make changes to this class,
     /// instead, put additional code in the CurrentProductList class
     /// </summary>
     public class CurrentProductListBase
     {
         /// <summary>
         /// Gets or Sets ProductID
         /// </summary>
         public int ProductID { get; set; }

         /// <summary>
         /// Gets or Sets ProductName
         /// </summary>
         public string ProductName { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public CurrentProductListBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the CurrentProductList table
         /// </summary>
         public static int GetRecordCount()
         {
             return CurrentProductListDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of CurrentProductList sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static CurrentProductListCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return CurrentProductListDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of CurrentProductList sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static CurrentProductListCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return CurrentProductListDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "ProductID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares ProductID used for sorting
         /// </summary>
         public static Comparison<CurrentProductList> ByProductID = delegate(CurrentProductList x, CurrentProductList y)
         {
             return x.ProductID.CompareTo(y.ProductID);
         };

         /// <summary>
         /// Compares ProductName used for sorting
         /// </summary>
         public static Comparison<CurrentProductList> ByProductName = delegate(CurrentProductList x, CurrentProductList y)
         {
             string value1 = x.ProductName ?? String.Empty;
             string value2 = y.ProductName ?? String.Empty;
             return value1.CompareTo(value2);
         };

     }
}
