using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for Invoices.  Do not make changes to this class,
     /// instead, put additional code in the Invoices class
     /// </summary>
     public class InvoicesBase
     {
         /// <summary>
         /// Gets or Sets ShipName
         /// </summary>
         public string ShipName { get; set; }

         /// <summary>
         /// Gets or Sets ShipAddress
         /// </summary>
         public string ShipAddress { get; set; }

         /// <summary>
         /// Gets or Sets ShipCity
         /// </summary>
         public string ShipCity { get; set; }

         /// <summary>
         /// Gets or Sets ShipRegion
         /// </summary>
         public string ShipRegion { get; set; }

         /// <summary>
         /// Gets or Sets ShipPostalCode
         /// </summary>
         public string ShipPostalCode { get; set; }

         /// <summary>
         /// Gets or Sets ShipCountry
         /// </summary>
         public string ShipCountry { get; set; }

         /// <summary>
         /// Gets or Sets CustomerID
         /// </summary>
         public string CustomerID { get; set; }

         /// <summary>
         /// Gets or Sets CustomerName
         /// </summary>
         public string CustomerName { get; set; }

         /// <summary>
         /// Gets or Sets Address
         /// </summary>
         public string Address { get; set; }

         /// <summary>
         /// Gets or Sets City
         /// </summary>
         public string City { get; set; }

         /// <summary>
         /// Gets or Sets Region1
         /// </summary>
         public string Region1 { get; set; }

         /// <summary>
         /// Gets or Sets PostalCode
         /// </summary>
         public string PostalCode { get; set; }

         /// <summary>
         /// Gets or Sets Country
         /// </summary>
         public string Country { get; set; }

         /// <summary>
         /// Gets or Sets Salesperson
         /// </summary>
         public string Salesperson { get; set; }

         /// <summary>
         /// Gets or Sets OrderID
         /// </summary>
         public int OrderID { get; set; }

         /// <summary>
         /// Gets or Sets OrderDate
         /// </summary>
         public DateTime? OrderDate { get; set; }

         /// <summary>
         /// Gets or Sets RequiredDate
         /// </summary>
         public DateTime? RequiredDate { get; set; }

         /// <summary>
         /// Gets or Sets ShippedDate
         /// </summary>
         public DateTime? ShippedDate { get; set; }

         /// <summary>
         /// Gets or Sets ShipperName
         /// </summary>
         public string ShipperName { get; set; }

         /// <summary>
         /// Gets or Sets ProductID
         /// </summary>
         public int ProductID { get; set; }

         /// <summary>
         /// Gets or Sets ProductName
         /// </summary>
         public string ProductName { get; set; }

         /// <summary>
         /// Gets or Sets UnitPrice
         /// </summary>
         public decimal UnitPrice { get; set; }

         /// <summary>
         /// Gets or Sets UnitPriceTotal
         /// </summary>
         public decimal UnitPriceTotal { get; set; }

         /// <summary>
         /// Gets or Sets Quantity
         /// </summary>
         public Int16 Quantity { get; set; }

         /// <summary>
         /// Gets or Sets Discount
         /// </summary>
         public Single Discount { get; set; }

         /// <summary>
         /// Gets or Sets ExtendedPrice
         /// </summary>
         public decimal? ExtendedPrice { get; set; }

         /// <summary>
         /// Gets or Sets ExtendedPriceTotal
         /// </summary>
         public decimal ExtendedPriceTotal { get; set; }

         /// <summary>
         /// Gets or Sets Freight
         /// </summary>
         public decimal? Freight { get; set; }

         /// <summary>
         /// Gets or Sets FreightTotal
         /// </summary>
         public decimal FreightTotal { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public InvoicesBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the Invoices table
         /// </summary>
         public static int GetRecordCount()
         {
             return InvoicesDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of Invoices sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static InvoicesCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return InvoicesDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of Invoices sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static InvoicesCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return InvoicesDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "ShipName";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares ShipName used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipName = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipName ?? String.Empty;
             string value2 = y.ShipName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipAddress used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipAddress = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipAddress ?? String.Empty;
             string value2 = y.ShipAddress ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipCity used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipCity = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipCity ?? String.Empty;
             string value2 = y.ShipCity ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipRegion used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipRegion = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipRegion ?? String.Empty;
             string value2 = y.ShipRegion ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipPostalCode used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipPostalCode = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipPostalCode ?? String.Empty;
             string value2 = y.ShipPostalCode ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipCountry used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipCountry = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipCountry ?? String.Empty;
             string value2 = y.ShipCountry ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares CustomerID used for sorting
         /// </summary>
         public static Comparison<Invoices> ByCustomerID = delegate(Invoices x, Invoices y)
         {
             string value1 = x.CustomerID ?? String.Empty;
             string value2 = y.CustomerID ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares CustomerName used for sorting
         /// </summary>
         public static Comparison<Invoices> ByCustomerName = delegate(Invoices x, Invoices y)
         {
             string value1 = x.CustomerName ?? String.Empty;
             string value2 = y.CustomerName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Address used for sorting
         /// </summary>
         public static Comparison<Invoices> ByAddress = delegate(Invoices x, Invoices y)
         {
             string value1 = x.Address ?? String.Empty;
             string value2 = y.Address ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares City used for sorting
         /// </summary>
         public static Comparison<Invoices> ByCity = delegate(Invoices x, Invoices y)
         {
             string value1 = x.City ?? String.Empty;
             string value2 = y.City ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Region1 used for sorting
         /// </summary>
         public static Comparison<Invoices> ByRegion1 = delegate(Invoices x, Invoices y)
         {
             string value1 = x.Region1 ?? String.Empty;
             string value2 = y.Region1 ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares PostalCode used for sorting
         /// </summary>
         public static Comparison<Invoices> ByPostalCode = delegate(Invoices x, Invoices y)
         {
             string value1 = x.PostalCode ?? String.Empty;
             string value2 = y.PostalCode ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Country used for sorting
         /// </summary>
         public static Comparison<Invoices> ByCountry = delegate(Invoices x, Invoices y)
         {
             string value1 = x.Country ?? String.Empty;
             string value2 = y.Country ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Salesperson used for sorting
         /// </summary>
         public static Comparison<Invoices> BySalesperson = delegate(Invoices x, Invoices y)
         {
             string value1 = x.Salesperson ?? String.Empty;
             string value2 = y.Salesperson ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares OrderID used for sorting
         /// </summary>
         public static Comparison<Invoices> ByOrderID = delegate(Invoices x, Invoices y)
         {
             return x.OrderID.CompareTo(y.OrderID);
         };

         /// <summary>
         /// Compares OrderDate used for sorting
         /// </summary>
         public static Comparison<Invoices> ByOrderDate = delegate(Invoices x, Invoices y)
         {
             return Nullable.Compare(x.OrderDate, y.OrderDate);
         };

         /// <summary>
         /// Compares RequiredDate used for sorting
         /// </summary>
         public static Comparison<Invoices> ByRequiredDate = delegate(Invoices x, Invoices y)
         {
             return Nullable.Compare(x.RequiredDate, y.RequiredDate);
         };

         /// <summary>
         /// Compares ShippedDate used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShippedDate = delegate(Invoices x, Invoices y)
         {
             return Nullable.Compare(x.ShippedDate, y.ShippedDate);
         };

         /// <summary>
         /// Compares ShipperName used for sorting
         /// </summary>
         public static Comparison<Invoices> ByShipperName = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ShipperName ?? String.Empty;
             string value2 = y.ShipperName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ProductID used for sorting
         /// </summary>
         public static Comparison<Invoices> ByProductID = delegate(Invoices x, Invoices y)
         {
             return x.ProductID.CompareTo(y.ProductID);
         };

         /// <summary>
         /// Compares ProductName used for sorting
         /// </summary>
         public static Comparison<Invoices> ByProductName = delegate(Invoices x, Invoices y)
         {
             string value1 = x.ProductName ?? String.Empty;
             string value2 = y.ProductName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares UnitPrice used for sorting
         /// </summary>
         public static Comparison<Invoices> ByUnitPrice = delegate(Invoices x, Invoices y)
         {
             return x.UnitPrice.CompareTo(y.UnitPrice);
         };

         /// <summary>
         /// Compares Quantity used for sorting
         /// </summary>
         public static Comparison<Invoices> ByQuantity = delegate(Invoices x, Invoices y)
         {
             return x.Quantity.CompareTo(y.Quantity);
         };

         /// <summary>
         /// Compares Discount used for sorting
         /// </summary>
         public static Comparison<Invoices> ByDiscount = delegate(Invoices x, Invoices y)
         {
             return x.Discount.CompareTo(y.Discount);
         };

         /// <summary>
         /// Compares ExtendedPrice used for sorting
         /// </summary>
         public static Comparison<Invoices> ByExtendedPrice = delegate(Invoices x, Invoices y)
         {
             return Nullable.Compare(x.ExtendedPrice, y.ExtendedPrice);
         };

         /// <summary>
         /// Compares Freight used for sorting
         /// </summary>
         public static Comparison<Invoices> ByFreight = delegate(Invoices x, Invoices y)
         {
             return Nullable.Compare(x.Freight, y.Freight);
         };

     }
}
