using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for OrderDetailsExtended.  Do not make changes to this class,
     /// instead, put additional code in the OrderDetailsExtended class
     /// </summary>
     public class OrderDetailsExtendedBase
     {
         /// <summary>
         /// Gets or Sets OrderID
         /// </summary>
         public int OrderID { get; set; }

         /// <summary>
         /// Gets or Sets ProductID
         /// </summary>
         public int ProductID { get; set; }

         /// <summary>
         /// Gets or Sets ProductName
         /// </summary>
         public string ProductName { get; set; }

         /// <summary>
         /// Gets or Sets UnitPrice
         /// </summary>
         public decimal UnitPrice { get; set; }

         /// <summary>
         /// Gets or Sets UnitPriceTotal
         /// </summary>
         public decimal UnitPriceTotal { get; set; }

         /// <summary>
         /// Gets or Sets Quantity
         /// </summary>
         public Int16 Quantity { get; set; }

         /// <summary>
         /// Gets or Sets Discount
         /// </summary>
         public Single Discount { get; set; }

         /// <summary>
         /// Gets or Sets ExtendedPrice
         /// </summary>
         public decimal? ExtendedPrice { get; set; }

         /// <summary>
         /// Gets or Sets ExtendedPriceTotal
         /// </summary>
         public decimal ExtendedPriceTotal { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public OrderDetailsExtendedBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the OrderDetailsExtended table
         /// </summary>
         public static int GetRecordCount()
         {
             return OrderDetailsExtendedDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of OrderDetailsExtended sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static OrderDetailsExtendedCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return OrderDetailsExtendedDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of OrderDetailsExtended sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static OrderDetailsExtendedCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return OrderDetailsExtendedDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "OrderID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares OrderID used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByOrderID = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             return x.OrderID.CompareTo(y.OrderID);
         };

         /// <summary>
         /// Compares ProductID used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByProductID = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             return x.ProductID.CompareTo(y.ProductID);
         };

         /// <summary>
         /// Compares ProductName used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByProductName = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             string value1 = x.ProductName ?? String.Empty;
             string value2 = y.ProductName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares UnitPrice used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByUnitPrice = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             return x.UnitPrice.CompareTo(y.UnitPrice);
         };

         /// <summary>
         /// Compares Quantity used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByQuantity = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             return x.Quantity.CompareTo(y.Quantity);
         };

         /// <summary>
         /// Compares Discount used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByDiscount = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             return x.Discount.CompareTo(y.Discount);
         };

         /// <summary>
         /// Compares ExtendedPrice used for sorting
         /// </summary>
         public static Comparison<OrderDetailsExtended> ByExtendedPrice = delegate(OrderDetailsExtended x, OrderDetailsExtended y)
         {
             return Nullable.Compare(x.ExtendedPrice, y.ExtendedPrice);
         };

     }
}
