using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for OrderSubtotals.  Do not make changes to this class,
     /// instead, put additional code in the OrderSubtotals class
     /// </summary>
     public class OrderSubtotalsBase
     {
         /// <summary>
         /// Gets or Sets OrderID
         /// </summary>
         public int OrderID { get; set; }

         /// <summary>
         /// Gets or Sets Subtotal
         /// </summary>
         public decimal? Subtotal { get; set; }

         /// <summary>
         /// Gets or Sets SubtotalTotal
         /// </summary>
         public decimal SubtotalTotal { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public OrderSubtotalsBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the OrderSubtotals table
         /// </summary>
         public static int GetRecordCount()
         {
             return OrderSubtotalsDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of OrderSubtotals sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static OrderSubtotalsCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return OrderSubtotalsDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of OrderSubtotals sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static OrderSubtotalsCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return OrderSubtotalsDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "OrderID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares OrderID used for sorting
         /// </summary>
         public static Comparison<OrderSubtotals> ByOrderID = delegate(OrderSubtotals x, OrderSubtotals y)
         {
             return x.OrderID.CompareTo(y.OrderID);
         };

         /// <summary>
         /// Compares Subtotal used for sorting
         /// </summary>
         public static Comparison<OrderSubtotals> BySubtotal = delegate(OrderSubtotals x, OrderSubtotals y)
         {
             return Nullable.Compare(x.Subtotal, y.Subtotal);
         };

     }
}
