using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for OrdersQry.  Do not make changes to this class,
     /// instead, put additional code in the OrdersQry class
     /// </summary>
     public class OrdersQryBase
     {
         /// <summary>
         /// Gets or Sets OrderID
         /// </summary>
         public int OrderID { get; set; }

         /// <summary>
         /// Gets or Sets CustomerID
         /// </summary>
         public string CustomerID { get; set; }

         /// <summary>
         /// Gets or Sets EmployeeID
         /// </summary>
         public int? EmployeeID { get; set; }

         /// <summary>
         /// Gets or Sets OrderDate
         /// </summary>
         public DateTime? OrderDate { get; set; }

         /// <summary>
         /// Gets or Sets RequiredDate
         /// </summary>
         public DateTime? RequiredDate { get; set; }

         /// <summary>
         /// Gets or Sets ShippedDate
         /// </summary>
         public DateTime? ShippedDate { get; set; }

         /// <summary>
         /// Gets or Sets ShipVia
         /// </summary>
         public int? ShipVia { get; set; }

         /// <summary>
         /// Gets or Sets Freight
         /// </summary>
         public decimal? Freight { get; set; }

         /// <summary>
         /// Gets or Sets FreightTotal
         /// </summary>
         public decimal FreightTotal { get; set; }

         /// <summary>
         /// Gets or Sets ShipName
         /// </summary>
         public string ShipName { get; set; }

         /// <summary>
         /// Gets or Sets ShipAddress
         /// </summary>
         public string ShipAddress { get; set; }

         /// <summary>
         /// Gets or Sets ShipCity
         /// </summary>
         public string ShipCity { get; set; }

         /// <summary>
         /// Gets or Sets ShipRegion
         /// </summary>
         public string ShipRegion { get; set; }

         /// <summary>
         /// Gets or Sets ShipPostalCode
         /// </summary>
         public string ShipPostalCode { get; set; }

         /// <summary>
         /// Gets or Sets ShipCountry
         /// </summary>
         public string ShipCountry { get; set; }

         /// <summary>
         /// Gets or Sets CompanyName
         /// </summary>
         public string CompanyName { get; set; }

         /// <summary>
         /// Gets or Sets Address
         /// </summary>
         public string Address { get; set; }

         /// <summary>
         /// Gets or Sets City
         /// </summary>
         public string City { get; set; }

         /// <summary>
         /// Gets or Sets Region1
         /// </summary>
         public string Region1 { get; set; }

         /// <summary>
         /// Gets or Sets PostalCode
         /// </summary>
         public string PostalCode { get; set; }

         /// <summary>
         /// Gets or Sets Country
         /// </summary>
         public string Country { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public OrdersQryBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the OrdersQry table
         /// </summary>
         public static int GetRecordCount()
         {
             return OrdersQryDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of OrdersQry sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static OrdersQryCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return OrdersQryDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of OrdersQry sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static OrdersQryCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return OrdersQryDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "OrderID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares OrderID used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByOrderID = delegate(OrdersQry x, OrdersQry y)
         {
             return x.OrderID.CompareTo(y.OrderID);
         };

         /// <summary>
         /// Compares CustomerID used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByCustomerID = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.CustomerID ?? String.Empty;
             string value2 = y.CustomerID ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares EmployeeID used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByEmployeeID = delegate(OrdersQry x, OrdersQry y)
         {
             return Nullable.Compare(x.EmployeeID, y.EmployeeID);
         };

         /// <summary>
         /// Compares OrderDate used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByOrderDate = delegate(OrdersQry x, OrdersQry y)
         {
             return Nullable.Compare(x.OrderDate, y.OrderDate);
         };

         /// <summary>
         /// Compares RequiredDate used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByRequiredDate = delegate(OrdersQry x, OrdersQry y)
         {
             return Nullable.Compare(x.RequiredDate, y.RequiredDate);
         };

         /// <summary>
         /// Compares ShippedDate used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShippedDate = delegate(OrdersQry x, OrdersQry y)
         {
             return Nullable.Compare(x.ShippedDate, y.ShippedDate);
         };

         /// <summary>
         /// Compares ShipVia used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipVia = delegate(OrdersQry x, OrdersQry y)
         {
             return Nullable.Compare(x.ShipVia, y.ShipVia);
         };

         /// <summary>
         /// Compares Freight used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByFreight = delegate(OrdersQry x, OrdersQry y)
         {
             return Nullable.Compare(x.Freight, y.Freight);
         };

         /// <summary>
         /// Compares ShipName used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipName = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.ShipName ?? String.Empty;
             string value2 = y.ShipName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipAddress used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipAddress = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.ShipAddress ?? String.Empty;
             string value2 = y.ShipAddress ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipCity used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipCity = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.ShipCity ?? String.Empty;
             string value2 = y.ShipCity ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipRegion used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipRegion = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.ShipRegion ?? String.Empty;
             string value2 = y.ShipRegion ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipPostalCode used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipPostalCode = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.ShipPostalCode ?? String.Empty;
             string value2 = y.ShipPostalCode ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShipCountry used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByShipCountry = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.ShipCountry ?? String.Empty;
             string value2 = y.ShipCountry ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares CompanyName used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByCompanyName = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.CompanyName ?? String.Empty;
             string value2 = y.CompanyName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Address used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByAddress = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.Address ?? String.Empty;
             string value2 = y.Address ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares City used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByCity = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.City ?? String.Empty;
             string value2 = y.City ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Region1 used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByRegion1 = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.Region1 ?? String.Empty;
             string value2 = y.Region1 ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares PostalCode used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByPostalCode = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.PostalCode ?? String.Empty;
             string value2 = y.PostalCode ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Country used for sorting
         /// </summary>
         public static Comparison<OrdersQry> ByCountry = delegate(OrdersQry x, OrdersQry y)
         {
             string value1 = x.Country ?? String.Empty;
             string value2 = y.Country ?? String.Empty;
             return value1.CompareTo(value2);
         };

     }
}
