using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for ProductsByCategory.  Do not make changes to this class,
     /// instead, put additional code in the ProductsByCategory class
     /// </summary>
     public class ProductsByCategoryBase
     {
         /// <summary>
         /// Gets or Sets CategoryName
         /// </summary>
         public string CategoryName { get; set; }

         /// <summary>
         /// Gets or Sets ProductName
         /// </summary>
         public string ProductName { get; set; }

         /// <summary>
         /// Gets or Sets QuantityPerUnit
         /// </summary>
         public string QuantityPerUnit { get; set; }

         /// <summary>
         /// Gets or Sets UnitsInStock
         /// </summary>
         public Int16? UnitsInStock { get; set; }

         /// <summary>
         /// Gets or Sets Discontinued
         /// </summary>
         public bool Discontinued { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public ProductsByCategoryBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the ProductsByCategory table
         /// </summary>
         public static int GetRecordCount()
         {
             return ProductsByCategoryDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of ProductsByCategory sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static ProductsByCategoryCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return ProductsByCategoryDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of ProductsByCategory sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static ProductsByCategoryCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return ProductsByCategoryDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "CategoryName";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares CategoryName used for sorting
         /// </summary>
         public static Comparison<ProductsByCategory> ByCategoryName = delegate(ProductsByCategory x, ProductsByCategory y)
         {
             string value1 = x.CategoryName ?? String.Empty;
             string value2 = y.CategoryName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ProductName used for sorting
         /// </summary>
         public static Comparison<ProductsByCategory> ByProductName = delegate(ProductsByCategory x, ProductsByCategory y)
         {
             string value1 = x.ProductName ?? String.Empty;
             string value2 = y.ProductName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares QuantityPerUnit used for sorting
         /// </summary>
         public static Comparison<ProductsByCategory> ByQuantityPerUnit = delegate(ProductsByCategory x, ProductsByCategory y)
         {
             string value1 = x.QuantityPerUnit ?? String.Empty;
             string value2 = y.QuantityPerUnit ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares UnitsInStock used for sorting
         /// </summary>
         public static Comparison<ProductsByCategory> ByUnitsInStock = delegate(ProductsByCategory x, ProductsByCategory y)
         {
             return Nullable.Compare(x.UnitsInStock, y.UnitsInStock);
         };

         /// <summary>
         /// Compares Discontinued used for sorting
         /// </summary>
         public static Comparison<ProductsByCategory> ByDiscontinued = delegate(ProductsByCategory x, ProductsByCategory y)
         {
             return x.Discontinued.CompareTo(y.Discontinued);
         };

     }
}
