using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for QuarterlyOrders.  Do not make changes to this class,
     /// instead, put additional code in the QuarterlyOrders class
     /// </summary>
     public class QuarterlyOrdersBase
     {
         /// <summary>
         /// Gets or Sets CustomerID
         /// </summary>
         public string CustomerID { get; set; }

         /// <summary>
         /// Gets or Sets CompanyName
         /// </summary>
         public string CompanyName { get; set; }

         /// <summary>
         /// Gets or Sets City
         /// </summary>
         public string City { get; set; }

         /// <summary>
         /// Gets or Sets Country
         /// </summary>
         public string Country { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public QuarterlyOrdersBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the QuarterlyOrders table
         /// </summary>
         public static int GetRecordCount()
         {
             return QuarterlyOrdersDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of QuarterlyOrders sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static QuarterlyOrdersCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return QuarterlyOrdersDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of QuarterlyOrders sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static QuarterlyOrdersCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return QuarterlyOrdersDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "CustomerID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares CustomerID used for sorting
         /// </summary>
         public static Comparison<QuarterlyOrders> ByCustomerID = delegate(QuarterlyOrders x, QuarterlyOrders y)
         {
             string value1 = x.CustomerID ?? String.Empty;
             string value2 = y.CustomerID ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares CompanyName used for sorting
         /// </summary>
         public static Comparison<QuarterlyOrders> ByCompanyName = delegate(QuarterlyOrders x, QuarterlyOrders y)
         {
             string value1 = x.CompanyName ?? String.Empty;
             string value2 = y.CompanyName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares City used for sorting
         /// </summary>
         public static Comparison<QuarterlyOrders> ByCity = delegate(QuarterlyOrders x, QuarterlyOrders y)
         {
             string value1 = x.City ?? String.Empty;
             string value2 = y.City ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares Country used for sorting
         /// </summary>
         public static Comparison<QuarterlyOrders> ByCountry = delegate(QuarterlyOrders x, QuarterlyOrders y)
         {
             string value1 = x.Country ?? String.Empty;
             string value2 = y.Country ?? String.Empty;
             return value1.CompareTo(value2);
         };

     }
}
