using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for SalesByCategory.  Do not make changes to this class,
     /// instead, put additional code in the SalesByCategory class
     /// </summary>
     public class SalesByCategoryBase
     {
         /// <summary>
         /// Gets or Sets CategoryID
         /// </summary>
         public int CategoryID { get; set; }

         /// <summary>
         /// Gets or Sets CategoryName
         /// </summary>
         public string CategoryName { get; set; }

         /// <summary>
         /// Gets or Sets ProductName
         /// </summary>
         public string ProductName { get; set; }

         /// <summary>
         /// Gets or Sets ProductSales
         /// </summary>
         public decimal? ProductSales { get; set; }

         /// <summary>
         /// Gets or Sets ProductSalesTotal
         /// </summary>
         public decimal ProductSalesTotal { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public SalesByCategoryBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the SalesByCategory table
         /// </summary>
         public static int GetRecordCount()
         {
             return SalesByCategoryDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of SalesByCategory sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static SalesByCategoryCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return SalesByCategoryDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of SalesByCategory sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static SalesByCategoryCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return SalesByCategoryDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "CategoryID";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares CategoryID used for sorting
         /// </summary>
         public static Comparison<SalesByCategory> ByCategoryID = delegate(SalesByCategory x, SalesByCategory y)
         {
             return x.CategoryID.CompareTo(y.CategoryID);
         };

         /// <summary>
         /// Compares CategoryName used for sorting
         /// </summary>
         public static Comparison<SalesByCategory> ByCategoryName = delegate(SalesByCategory x, SalesByCategory y)
         {
             string value1 = x.CategoryName ?? String.Empty;
             string value2 = y.CategoryName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ProductName used for sorting
         /// </summary>
         public static Comparison<SalesByCategory> ByProductName = delegate(SalesByCategory x, SalesByCategory y)
         {
             string value1 = x.ProductName ?? String.Empty;
             string value2 = y.ProductName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ProductSales used for sorting
         /// </summary>
         public static Comparison<SalesByCategory> ByProductSales = delegate(SalesByCategory x, SalesByCategory y)
         {
             return Nullable.Compare(x.ProductSales, y.ProductSales);
         };

     }
}
