using System;
using System.Data;
using NorthwindWinFormViewsDynamic_CS.DataLayer;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;

namespace NorthwindWinFormViewsDynamic_CS.BusinessObject.Base
{
     /// <summary>
     /// Base class for SalesTotalsByAmount.  Do not make changes to this class,
     /// instead, put additional code in the SalesTotalsByAmount class
     /// </summary>
     public class SalesTotalsByAmountBase
     {
         /// <summary>
         /// Gets or Sets SaleAmount
         /// </summary>
         public decimal? SaleAmount { get; set; }

         /// <summary>
         /// Gets or Sets SaleAmountTotal
         /// </summary>
         public decimal SaleAmountTotal { get; set; }

         /// <summary>
         /// Gets or Sets OrderID
         /// </summary>
         public int OrderID { get; set; }

         /// <summary>
         /// Gets or Sets CompanyName
         /// </summary>
         public string CompanyName { get; set; }

         /// <summary>
         /// Gets or Sets ShippedDate
         /// </summary>
         public DateTime? ShippedDate { get; set; }


         /// <summary>
         /// Constructor
         /// </summary>
         public SalesTotalsByAmountBase()
         {
         }

         /// <summary>
         /// Gets the total number of records in the SalesTotalsByAmount table
         /// </summary>
         public static int GetRecordCount()
         {
             return SalesTotalsByAmountDataLayer.GetRecordCount();
         }

         /// <summary>
         /// Selects records as a collection (List) of SalesTotalsByAmount sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         /// </summary>
         public static SalesTotalsByAmountCollection SelectSkipAndTake(int rows, int startRowIndex, out int totalRowCount, string sortByExpression)
         {
             totalRowCount = GetRecordCount();
             sortByExpression = GetSortExpression(sortByExpression);

             return SalesTotalsByAmountDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Selects records as a collection (List) of SalesTotalsByAmount sorted by the sortByExpression starting from the startRowIndex.
         /// </summary>
         public static SalesTotalsByAmountCollection SelectSkipAndTake(int rows, int startRowIndex, string sortByExpression)
         {
             sortByExpression = GetSortExpression(sortByExpression);
             return SalesTotalsByAmountDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows);
         }

         private static string GetSortExpression(string sortByExpression)
         {
             if (String.IsNullOrEmpty(sortByExpression) || sortByExpression == " asc")
                 sortByExpression = "SaleAmount";
             else if (sortByExpression.Contains(" asc"))
                 sortByExpression = sortByExpression.Replace(" asc", "");

             return sortByExpression;
         }

         /// <summary>
         /// Compares SaleAmount used for sorting
         /// </summary>
         public static Comparison<SalesTotalsByAmount> BySaleAmount = delegate(SalesTotalsByAmount x, SalesTotalsByAmount y)
         {
             return Nullable.Compare(x.SaleAmount, y.SaleAmount);
         };

         /// <summary>
         /// Compares OrderID used for sorting
         /// </summary>
         public static Comparison<SalesTotalsByAmount> ByOrderID = delegate(SalesTotalsByAmount x, SalesTotalsByAmount y)
         {
             return x.OrderID.CompareTo(y.OrderID);
         };

         /// <summary>
         /// Compares CompanyName used for sorting
         /// </summary>
         public static Comparison<SalesTotalsByAmount> ByCompanyName = delegate(SalesTotalsByAmount x, SalesTotalsByAmount y)
         {
             string value1 = x.CompanyName ?? String.Empty;
             string value2 = y.CompanyName ?? String.Empty;
             return value1.CompareTo(value2);
         };

         /// <summary>
         /// Compares ShippedDate used for sorting
         /// </summary>
         public static Comparison<SalesTotalsByAmount> ByShippedDate = delegate(SalesTotalsByAmount x, SalesTotalsByAmount y)
         {
             return Nullable.Compare(x.ShippedDate, y.ShippedDate);
         };

     }
}
