using System;
using System.Data;
using System.Data.SqlClient;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using System.Configuration;

namespace NorthwindWinFormViewsDynamic_CS.DataLayer.Base
{
     /// <summary>
     /// Base class for InvoicesDataLayer.  Do not make changes to this class,
     /// instead, put additional code in the InvoicesDataLayer class
     /// </summary>
     public class InvoicesDataLayerBase
     {
         // constructor
         public InvoicesDataLayerBase()
         {
         }

         public static InvoicesCollection SelectShared(string dynamicSqlScript, string param, object paramValue, string sortByExpression = null, int? startRowIndex = null, int? rows = null)
         {
              InvoicesCollection objInvoicesCol = null;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      // select, skip, take, sort parameters
                      if (!String.IsNullOrEmpty(sortByExpression) && startRowIndex != null && rows != null)
                      {
                          command.Parameters.AddWithValue("@start", startRowIndex.Value);
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value);
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression);
                      }

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  objInvoicesCol = new InvoicesCollection();

                                  foreach (DataRow dr in dt.Rows)
                                  {
                                      Invoices objInvoices = CreateInvoicesFromDataRowShared(dr);
                                      objInvoicesCol.Add(objInvoices);
                                  }
                              }
                          }
                      }
                  }
              }

              return objInvoicesCol;
         }

         /// <summary>
         /// Gets the total number of records in the Invoices table
         /// </summary>
         public static int GetRecordCount()
         {
             string sql = InvoicesSql.GetRecordCount();
             return GetRecordCountShared(null, null, null, false, sql);
         }

         public static int GetRecordCountShared(string storedProcName = null, string param = null, object paramValue = null, bool isUseStoredProc = true, string dynamicSqlScript = null)
         {
              int recordCount = 0;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  recordCount = (int)dt.Rows[0]["RecordCount"];
                              }
                          }
                      }
                  }
              }

              return recordCount;
         }

         /// <summary>
         /// Selects Invoices records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of rows)
         /// </summary>
         public static InvoicesCollection SelectSkipAndTake(string sortByExpression, int startRowIndex, int rows)
         {
             string dynamicSqlScript = InvoicesSql.SelectSkipAndTake();
             return SelectShared(dynamicSqlScript, null, null, sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Creates a Invoices object from the passed data row
         /// </summary>
         private static Invoices CreateInvoicesFromDataRowShared(DataRow dr)
         {
             Invoices objInvoices = new Invoices();


             if (dr["ShipName"] != System.DBNull.Value)
                 objInvoices.ShipName = dr["ShipName"].ToString();
             else
                 objInvoices.ShipName = null;

             if (dr["ShipAddress"] != System.DBNull.Value)
                 objInvoices.ShipAddress = dr["ShipAddress"].ToString();
             else
                 objInvoices.ShipAddress = null;

             if (dr["ShipCity"] != System.DBNull.Value)
                 objInvoices.ShipCity = dr["ShipCity"].ToString();
             else
                 objInvoices.ShipCity = null;

             if (dr["ShipRegion"] != System.DBNull.Value)
                 objInvoices.ShipRegion = dr["ShipRegion"].ToString();
             else
                 objInvoices.ShipRegion = null;

             if (dr["ShipPostalCode"] != System.DBNull.Value)
                 objInvoices.ShipPostalCode = dr["ShipPostalCode"].ToString();
             else
                 objInvoices.ShipPostalCode = null;

             if (dr["ShipCountry"] != System.DBNull.Value)
                 objInvoices.ShipCountry = dr["ShipCountry"].ToString();
             else
                 objInvoices.ShipCountry = null;

             if (dr["CustomerID"] != System.DBNull.Value)
                 objInvoices.CustomerID = dr["CustomerID"].ToString();
             else
                 objInvoices.CustomerID = null;
             objInvoices.CustomerName = dr["CustomerName"].ToString();

             if (dr["Address"] != System.DBNull.Value)
                 objInvoices.Address = dr["Address"].ToString();
             else
                 objInvoices.Address = null;

             if (dr["City"] != System.DBNull.Value)
                 objInvoices.City = dr["City"].ToString();
             else
                 objInvoices.City = null;

             if (dr["Region1"] != System.DBNull.Value)
                 objInvoices.Region1 = dr["Region1"].ToString();
             else
                 objInvoices.Region1 = null;

             if (dr["PostalCode"] != System.DBNull.Value)
                 objInvoices.PostalCode = dr["PostalCode"].ToString();
             else
                 objInvoices.PostalCode = null;

             if (dr["Country"] != System.DBNull.Value)
                 objInvoices.Country = dr["Country"].ToString();
             else
                 objInvoices.Country = null;
             objInvoices.Salesperson = dr["Salesperson"].ToString();
             objInvoices.OrderID = (int)dr["OrderID"];

             if (dr["OrderDate"] != System.DBNull.Value)
                 objInvoices.OrderDate = (DateTime)dr["OrderDate"];
             else
                 objInvoices.OrderDate = null;

             if (dr["RequiredDate"] != System.DBNull.Value)
                 objInvoices.RequiredDate = (DateTime)dr["RequiredDate"];
             else
                 objInvoices.RequiredDate = null;

             if (dr["ShippedDate"] != System.DBNull.Value)
                 objInvoices.ShippedDate = (DateTime)dr["ShippedDate"];
             else
                 objInvoices.ShippedDate = null;
             objInvoices.ShipperName = dr["ShipperName"].ToString();
             objInvoices.ProductID = (int)dr["ProductID"];
             objInvoices.ProductName = dr["ProductName"].ToString();
             objInvoices.UnitPrice = (decimal)dr["UnitPrice"];
             objInvoices.Quantity = (Int16)dr["Quantity"];
             objInvoices.Discount = (Single)dr["Discount"];

             if (dr["ExtendedPrice"] != System.DBNull.Value)
                 objInvoices.ExtendedPrice = (decimal)dr["ExtendedPrice"];
             else
                 objInvoices.ExtendedPrice = null;

             if (dr["Freight"] != System.DBNull.Value)
                 objInvoices.Freight = (decimal)dr["Freight"];
             else
                 objInvoices.Freight = null;

             return objInvoices;
         }
     }
}
