using System;
using System.Data;
using System.Data.SqlClient;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using System.Configuration;

namespace NorthwindWinFormViewsDynamic_CS.DataLayer.Base
{
     /// <summary>
     /// Base class for OrderDetailsExtendedDataLayer.  Do not make changes to this class,
     /// instead, put additional code in the OrderDetailsExtendedDataLayer class
     /// </summary>
     public class OrderDetailsExtendedDataLayerBase
     {
         // constructor
         public OrderDetailsExtendedDataLayerBase()
         {
         }

         public static OrderDetailsExtendedCollection SelectShared(string dynamicSqlScript, string param, object paramValue, string sortByExpression = null, int? startRowIndex = null, int? rows = null)
         {
              OrderDetailsExtendedCollection objOrderDetailsExtendedCol = null;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      // select, skip, take, sort parameters
                      if (!String.IsNullOrEmpty(sortByExpression) && startRowIndex != null && rows != null)
                      {
                          command.Parameters.AddWithValue("@start", startRowIndex.Value);
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value);
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression);
                      }

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  objOrderDetailsExtendedCol = new OrderDetailsExtendedCollection();

                                  foreach (DataRow dr in dt.Rows)
                                  {
                                      OrderDetailsExtended objOrderDetailsExtended = CreateOrderDetailsExtendedFromDataRowShared(dr);
                                      objOrderDetailsExtendedCol.Add(objOrderDetailsExtended);
                                  }
                              }
                          }
                      }
                  }
              }

              return objOrderDetailsExtendedCol;
         }

         /// <summary>
         /// Gets the total number of records in the OrderDetailsExtended table
         /// </summary>
         public static int GetRecordCount()
         {
             string sql = OrderDetailsExtendedSql.GetRecordCount();
             return GetRecordCountShared(null, null, null, false, sql);
         }

         public static int GetRecordCountShared(string storedProcName = null, string param = null, object paramValue = null, bool isUseStoredProc = true, string dynamicSqlScript = null)
         {
              int recordCount = 0;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  recordCount = (int)dt.Rows[0]["RecordCount"];
                              }
                          }
                      }
                  }
              }

              return recordCount;
         }

         /// <summary>
         /// Selects OrderDetailsExtended records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of rows)
         /// </summary>
         public static OrderDetailsExtendedCollection SelectSkipAndTake(string sortByExpression, int startRowIndex, int rows)
         {
             string dynamicSqlScript = OrderDetailsExtendedSql.SelectSkipAndTake();
             return SelectShared(dynamicSqlScript, null, null, sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Creates a OrderDetailsExtended object from the passed data row
         /// </summary>
         private static OrderDetailsExtended CreateOrderDetailsExtendedFromDataRowShared(DataRow dr)
         {
             OrderDetailsExtended objOrderDetailsExtended = new OrderDetailsExtended();

             objOrderDetailsExtended.OrderID = (int)dr["OrderID"];
             objOrderDetailsExtended.ProductID = (int)dr["ProductID"];
             objOrderDetailsExtended.ProductName = dr["ProductName"].ToString();
             objOrderDetailsExtended.UnitPrice = (decimal)dr["UnitPrice"];
             objOrderDetailsExtended.Quantity = (Int16)dr["Quantity"];
             objOrderDetailsExtended.Discount = (Single)dr["Discount"];

             if (dr["ExtendedPrice"] != System.DBNull.Value)
                 objOrderDetailsExtended.ExtendedPrice = (decimal)dr["ExtendedPrice"];
             else
                 objOrderDetailsExtended.ExtendedPrice = null;

             return objOrderDetailsExtended;
         }
     }
}
