using System;
using System.Data;
using System.Data.SqlClient;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using System.Configuration;

namespace NorthwindWinFormViewsDynamic_CS.DataLayer.Base
{
     /// <summary>
     /// Base class for OrderSubtotalsDataLayer.  Do not make changes to this class,
     /// instead, put additional code in the OrderSubtotalsDataLayer class
     /// </summary>
     public class OrderSubtotalsDataLayerBase
     {
         // constructor
         public OrderSubtotalsDataLayerBase()
         {
         }

         public static OrderSubtotalsCollection SelectShared(string dynamicSqlScript, string param, object paramValue, string sortByExpression = null, int? startRowIndex = null, int? rows = null)
         {
              OrderSubtotalsCollection objOrderSubtotalsCol = null;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      // select, skip, take, sort parameters
                      if (!String.IsNullOrEmpty(sortByExpression) && startRowIndex != null && rows != null)
                      {
                          command.Parameters.AddWithValue("@start", startRowIndex.Value);
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value);
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression);
                      }

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  objOrderSubtotalsCol = new OrderSubtotalsCollection();

                                  foreach (DataRow dr in dt.Rows)
                                  {
                                      OrderSubtotals objOrderSubtotals = CreateOrderSubtotalsFromDataRowShared(dr);
                                      objOrderSubtotalsCol.Add(objOrderSubtotals);
                                  }
                              }
                          }
                      }
                  }
              }

              return objOrderSubtotalsCol;
         }

         /// <summary>
         /// Gets the total number of records in the OrderSubtotals table
         /// </summary>
         public static int GetRecordCount()
         {
             string sql = OrderSubtotalsSql.GetRecordCount();
             return GetRecordCountShared(null, null, null, false, sql);
         }

         public static int GetRecordCountShared(string storedProcName = null, string param = null, object paramValue = null, bool isUseStoredProc = true, string dynamicSqlScript = null)
         {
              int recordCount = 0;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  recordCount = (int)dt.Rows[0]["RecordCount"];
                              }
                          }
                      }
                  }
              }

              return recordCount;
         }

         /// <summary>
         /// Selects OrderSubtotals records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of rows)
         /// </summary>
         public static OrderSubtotalsCollection SelectSkipAndTake(string sortByExpression, int startRowIndex, int rows)
         {
             string dynamicSqlScript = OrderSubtotalsSql.SelectSkipAndTake();
             return SelectShared(dynamicSqlScript, null, null, sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Creates a OrderSubtotals object from the passed data row
         /// </summary>
         private static OrderSubtotals CreateOrderSubtotalsFromDataRowShared(DataRow dr)
         {
             OrderSubtotals objOrderSubtotals = new OrderSubtotals();

             objOrderSubtotals.OrderID = (int)dr["OrderID"];

             if (dr["Subtotal"] != System.DBNull.Value)
                 objOrderSubtotals.Subtotal = (decimal)dr["Subtotal"];
             else
                 objOrderSubtotals.Subtotal = null;

             return objOrderSubtotals;
         }
     }
}
