using System;
using System.Data;
using System.Data.SqlClient;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using System.Configuration;

namespace NorthwindWinFormViewsDynamic_CS.DataLayer.Base
{
     /// <summary>
     /// Base class for OrdersQryDataLayer.  Do not make changes to this class,
     /// instead, put additional code in the OrdersQryDataLayer class
     /// </summary>
     public class OrdersQryDataLayerBase
     {
         // constructor
         public OrdersQryDataLayerBase()
         {
         }

         public static OrdersQryCollection SelectShared(string dynamicSqlScript, string param, object paramValue, string sortByExpression = null, int? startRowIndex = null, int? rows = null)
         {
              OrdersQryCollection objOrdersQryCol = null;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      // select, skip, take, sort parameters
                      if (!String.IsNullOrEmpty(sortByExpression) && startRowIndex != null && rows != null)
                      {
                          command.Parameters.AddWithValue("@start", startRowIndex.Value);
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value);
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression);
                      }

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  objOrdersQryCol = new OrdersQryCollection();

                                  foreach (DataRow dr in dt.Rows)
                                  {
                                      OrdersQry objOrdersQry = CreateOrdersQryFromDataRowShared(dr);
                                      objOrdersQryCol.Add(objOrdersQry);
                                  }
                              }
                          }
                      }
                  }
              }

              return objOrdersQryCol;
         }

         /// <summary>
         /// Gets the total number of records in the OrdersQry table
         /// </summary>
         public static int GetRecordCount()
         {
             string sql = OrdersQrySql.GetRecordCount();
             return GetRecordCountShared(null, null, null, false, sql);
         }

         public static int GetRecordCountShared(string storedProcName = null, string param = null, object paramValue = null, bool isUseStoredProc = true, string dynamicSqlScript = null)
         {
              int recordCount = 0;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  recordCount = (int)dt.Rows[0]["RecordCount"];
                              }
                          }
                      }
                  }
              }

              return recordCount;
         }

         /// <summary>
         /// Selects OrdersQry records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of rows)
         /// </summary>
         public static OrdersQryCollection SelectSkipAndTake(string sortByExpression, int startRowIndex, int rows)
         {
             string dynamicSqlScript = OrdersQrySql.SelectSkipAndTake();
             return SelectShared(dynamicSqlScript, null, null, sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Creates a OrdersQry object from the passed data row
         /// </summary>
         private static OrdersQry CreateOrdersQryFromDataRowShared(DataRow dr)
         {
             OrdersQry objOrdersQry = new OrdersQry();

             objOrdersQry.OrderID = (int)dr["OrderID"];

             if (dr["CustomerID"] != System.DBNull.Value)
                 objOrdersQry.CustomerID = dr["CustomerID"].ToString();
             else
                 objOrdersQry.CustomerID = null;

             if (dr["EmployeeID"] != System.DBNull.Value)
                 objOrdersQry.EmployeeID = (int)dr["EmployeeID"];
             else
                 objOrdersQry.EmployeeID = null;

             if (dr["OrderDate"] != System.DBNull.Value)
                 objOrdersQry.OrderDate = (DateTime)dr["OrderDate"];
             else
                 objOrdersQry.OrderDate = null;

             if (dr["RequiredDate"] != System.DBNull.Value)
                 objOrdersQry.RequiredDate = (DateTime)dr["RequiredDate"];
             else
                 objOrdersQry.RequiredDate = null;

             if (dr["ShippedDate"] != System.DBNull.Value)
                 objOrdersQry.ShippedDate = (DateTime)dr["ShippedDate"];
             else
                 objOrdersQry.ShippedDate = null;

             if (dr["ShipVia"] != System.DBNull.Value)
                 objOrdersQry.ShipVia = (int)dr["ShipVia"];
             else
                 objOrdersQry.ShipVia = null;

             if (dr["Freight"] != System.DBNull.Value)
                 objOrdersQry.Freight = (decimal)dr["Freight"];
             else
                 objOrdersQry.Freight = null;

             if (dr["ShipName"] != System.DBNull.Value)
                 objOrdersQry.ShipName = dr["ShipName"].ToString();
             else
                 objOrdersQry.ShipName = null;

             if (dr["ShipAddress"] != System.DBNull.Value)
                 objOrdersQry.ShipAddress = dr["ShipAddress"].ToString();
             else
                 objOrdersQry.ShipAddress = null;

             if (dr["ShipCity"] != System.DBNull.Value)
                 objOrdersQry.ShipCity = dr["ShipCity"].ToString();
             else
                 objOrdersQry.ShipCity = null;

             if (dr["ShipRegion"] != System.DBNull.Value)
                 objOrdersQry.ShipRegion = dr["ShipRegion"].ToString();
             else
                 objOrdersQry.ShipRegion = null;

             if (dr["ShipPostalCode"] != System.DBNull.Value)
                 objOrdersQry.ShipPostalCode = dr["ShipPostalCode"].ToString();
             else
                 objOrdersQry.ShipPostalCode = null;

             if (dr["ShipCountry"] != System.DBNull.Value)
                 objOrdersQry.ShipCountry = dr["ShipCountry"].ToString();
             else
                 objOrdersQry.ShipCountry = null;
             objOrdersQry.CompanyName = dr["CompanyName"].ToString();

             if (dr["Address"] != System.DBNull.Value)
                 objOrdersQry.Address = dr["Address"].ToString();
             else
                 objOrdersQry.Address = null;

             if (dr["City"] != System.DBNull.Value)
                 objOrdersQry.City = dr["City"].ToString();
             else
                 objOrdersQry.City = null;

             if (dr["Region1"] != System.DBNull.Value)
                 objOrdersQry.Region1 = dr["Region1"].ToString();
             else
                 objOrdersQry.Region1 = null;

             if (dr["PostalCode"] != System.DBNull.Value)
                 objOrdersQry.PostalCode = dr["PostalCode"].ToString();
             else
                 objOrdersQry.PostalCode = null;

             if (dr["Country"] != System.DBNull.Value)
                 objOrdersQry.Country = dr["Country"].ToString();
             else
                 objOrdersQry.Country = null;

             return objOrdersQry;
         }
     }
}
