using System;
using System.Data;
using System.Data.SqlClient;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using System.Configuration;

namespace NorthwindWinFormViewsDynamic_CS.DataLayer.Base
{
     /// <summary>
     /// Base class for ProductsByCategoryDataLayer.  Do not make changes to this class,
     /// instead, put additional code in the ProductsByCategoryDataLayer class
     /// </summary>
     public class ProductsByCategoryDataLayerBase
     {
         // constructor
         public ProductsByCategoryDataLayerBase()
         {
         }

         public static ProductsByCategoryCollection SelectShared(string dynamicSqlScript, string param, object paramValue, string sortByExpression = null, int? startRowIndex = null, int? rows = null)
         {
              ProductsByCategoryCollection objProductsByCategoryCol = null;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      // select, skip, take, sort parameters
                      if (!String.IsNullOrEmpty(sortByExpression) && startRowIndex != null && rows != null)
                      {
                          command.Parameters.AddWithValue("@start", startRowIndex.Value);
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value);
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression);
                      }

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  objProductsByCategoryCol = new ProductsByCategoryCollection();

                                  foreach (DataRow dr in dt.Rows)
                                  {
                                      ProductsByCategory objProductsByCategory = CreateProductsByCategoryFromDataRowShared(dr);
                                      objProductsByCategoryCol.Add(objProductsByCategory);
                                  }
                              }
                          }
                      }
                  }
              }

              return objProductsByCategoryCol;
         }

         /// <summary>
         /// Gets the total number of records in the ProductsByCategory table
         /// </summary>
         public static int GetRecordCount()
         {
             string sql = ProductsByCategorySql.GetRecordCount();
             return GetRecordCountShared(null, null, null, false, sql);
         }

         public static int GetRecordCountShared(string storedProcName = null, string param = null, object paramValue = null, bool isUseStoredProc = true, string dynamicSqlScript = null)
         {
              int recordCount = 0;

              using (SqlConnection connection = new SqlConnection(ConfigurationManager.ConnectionStrings["ConnectionString"].ConnectionString))
              {
                  connection.Open();

                  using (SqlCommand command = new SqlCommand(dynamicSqlScript, connection))
                  {
                      command.CommandType = CommandType.Text;

                      using (SqlDataAdapter da = new SqlDataAdapter(command))
                      {
                          DataTable dt = new DataTable();
                          da.Fill(dt);

                          if (dt != null)
                          {
                              if (dt.Rows.Count > 0)
                              {
                                  recordCount = (int)dt.Rows[0]["RecordCount"];
                              }
                          }
                      }
                  }
              }

              return recordCount;
         }

         /// <summary>
         /// Selects ProductsByCategory records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of rows)
         /// </summary>
         public static ProductsByCategoryCollection SelectSkipAndTake(string sortByExpression, int startRowIndex, int rows)
         {
             string dynamicSqlScript = ProductsByCategorySql.SelectSkipAndTake();
             return SelectShared(dynamicSqlScript, null, null, sortByExpression, startRowIndex, rows);
         }

         /// <summary>
         /// Creates a ProductsByCategory object from the passed data row
         /// </summary>
         private static ProductsByCategory CreateProductsByCategoryFromDataRowShared(DataRow dr)
         {
             ProductsByCategory objProductsByCategory = new ProductsByCategory();

             objProductsByCategory.CategoryName = dr["CategoryName"].ToString();
             objProductsByCategory.ProductName = dr["ProductName"].ToString();

             if (dr["QuantityPerUnit"] != System.DBNull.Value)
                 objProductsByCategory.QuantityPerUnit = dr["QuantityPerUnit"].ToString();
             else
                 objProductsByCategory.QuantityPerUnit = null;

             if (dr["UnitsInStock"] != System.DBNull.Value)
                 objProductsByCategory.UnitsInStock = (Int16)dr["UnitsInStock"];
             else
                 objProductsByCategory.UnitsInStock = null;
             objProductsByCategory.Discontinued = (bool)dr["Discontinued"];

             return objProductsByCategory;
         }
     }
}
