using System;
using System.Windows.Forms;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using NorthwindWinFormViewsDynamic_CS.Domain;

namespace NorthwindWinFormViewsDynamic_CS
{
    public partial class ListReadOnlyCustomerAndSuppliersByCity : Form
    {
        int _currentRecordNumber = 1;
        int _currentPageNumber = 1;
        int _totalRecords = 0;
        int _totalNumberOfPages = 0;
        int _sortColumnIndex = 0;
        string _sortByExpression = "";
        SortOrder _sortOrder = SortOrder.Ascending;
        int _currentRowIndex;
        bool _isFireToolStripComboBoxSelectedIndexChanged;

        public ListReadOnlyCustomerAndSuppliersByCity()
        {
            InitializeComponent();
        }

        #region winform events

        private void ListReadOnlyCustomerAndSuppliersByCity_Load(object sender, EventArgs e)
        {
            SetGridProperties();
            SetGridColumnProperties();
            SetDataSource(false);
            ResetNavButtonsToDefault();

        }

        #endregion

        #region binding navigator control events

        private void BnvNavMoveFirstItem_Click(object sender, EventArgs e)
        {
            _currentRecordNumber = 1;
            _currentPageNumber = 1;
            MoveToFirstPage();
        }

        private void BnvNavMovePreviousItem_Click(object sender, EventArgs e)
        {
            _currentPageNumber--;
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            MoveToPrevious();
        }

        private void BnvNavMoveNextItem_Click(object sender, EventArgs e)
        {
            _currentPageNumber++;
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            MoveToNext();
        }

        private void BnvNavMoveLastItem_Click(object sender, EventArgs e)
        {
            _currentPageNumber = _totalNumberOfPages;
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            MoveToLastPage();
        }


        #endregion

        #region data gridview events

        private void DgvGrid_ColumnHeaderMouseClick(object sender, DataGridViewCellMouseEventArgs e)
        {
            _sortColumnIndex = e.ColumnIndex;
            SetDataSource(true);
        }

        private void DgvGrid_CellContextMenuStripNeeded(object sender, DataGridViewCellContextMenuStripNeededEventArgs e)
        {
            HightlightRow(e.RowIndex);
        }

        private void DgvGrid_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            // make sure the click did not come from the header
            if (e.RowIndex != -1)
                HightlightRow(e.RowIndex);
        }

        #endregion

        #region toolstrip menu item events

        private void TscbPage_SelectedIndexChanged(object sender, EventArgs e)
        {
            // make sure this event is not called 
            // when adding items to the tool strip combo box
            if (!_isFireToolStripComboBoxSelectedIndexChanged)
                return;

            // set current page number
            int lastVisitedPageNumber = _currentPageNumber;
            _currentPageNumber = (int)TscbPage.ComboBox.SelectedItem;

            if (_currentPageNumber == 1)
                _currentRecordNumber = 1;
            else
                _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            // go to the selected page
            if (_currentPageNumber == 1)
                MoveToFirstPage();
            else if (_currentPageNumber == _totalNumberOfPages)
                MoveToLastPage();
            else if (_currentPageNumber < lastVisitedPageNumber)
                MoveToPrevious();
            else
                MoveToNext();
        }

        #endregion

        #region private methods

        private void SetGridProperties()
        {
            DgvGrid.AutoGenerateColumns = false;
            DgvGrid.AllowUserToResizeRows = false;
            DgvGrid.ColumnCount = 4;
            DgvGrid.ScrollBars = ScrollBars.None;
            DgvGrid.AllowUserToOrderColumns = false;
            DgvGrid.AllowUserToAddRows = false;
            DgvGrid.AllowUserToDeleteRows = false;
            DgvGrid.ReadOnly = true;
        }

        private void SetGridColumnProperties()
        {
            DgvGrid.Columns["City"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["CompanyName"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ContactName"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["Relationship"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
        }

        private void MoveToFirstPage()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToFirst(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem);
        }

        private void MoveToPrevious()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToPrevious(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem, _currentRecordNumber);
        }

        private void MoveToNext()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToNext(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem, _currentPageNumber, _totalNumberOfPages);
        }

        private void MoveToLastPage()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToLast(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem);
        }

        private void SetDataSource(bool isSort)
        {
            if (isSort)
                _sortByExpression = GetSortByExpression();

            // fill the datagridview
            DgvGrid.DataSource = CustomerAndSuppliersByCity.SelectSkipAndTake(ConstantHelper.GridNumberOfRows, _currentRecordNumber, out _totalRecords, _sortByExpression);
            DgvGrid.Columns[_sortColumnIndex].HeaderCell.SortGlyphDirection = _sortOrder;

            if (_totalRecords > 0)
            {
                _totalNumberOfPages = (int)Math.Ceiling((float)_totalRecords / (float)ConstantHelper.GridNumberOfRows);
                TscbPage.ComboBox.Items.Clear();

                // fill page numbers in toolstripcombobox
                for (int page = 1; page <= _totalNumberOfPages; page++)
                {
                    _isFireToolStripComboBoxSelectedIndexChanged = false;
                    TscbPage.ComboBox.Items.Add(page);
                }

                TscbPage.ComboBox.SelectedItem = _currentPageNumber;
                _isFireToolStripComboBoxSelectedIndexChanged = true;
            }

            ResetNavButtonsToDefault();
        }

        private string GetSortByExpression()
        {
            _sortOrder = SortOrder.Descending;

            switch (_sortColumnIndex)
            {
                case 0:
                    if (_sortByExpression == "City")
                        return "City desc";

                    _sortOrder = SortOrder.Ascending;
                    return "City";

                case 1:
                    if (_sortByExpression == "CompanyName")
                        return "CompanyName desc";

                    _sortOrder = SortOrder.Ascending;
                    return "CompanyName";

                case 2:
                    if (_sortByExpression == "ContactName")
                        return "ContactName desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ContactName";

                case 3:
                    if (_sortByExpression == "Relationship")
                        return "Relationship desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Relationship";

                default:
                    if (_sortByExpression == "")
                        return " desc";

                    _sortOrder = SortOrder.Ascending;
                    return "";
            }
        }

        private void ResetNavButtonsToDefault()
        {
            BnvNavCountItem.Text = "of " + _totalNumberOfPages + " pages";

            if (_totalRecords <= ConstantHelper.GridNumberOfRows)
            {
                BnvNavMoveNextItem.Enabled = false;
                BnvNavMoveLastItem.Enabled = false;
            }
            else
            {
                BnvNavMoveNextItem.Enabled = true;
                BnvNavMoveLastItem.Enabled = true;
            }
        }

        private void HightlightRow(int rowIndex)
        {
            // highlight row
            DgvGrid.ClearSelection();
            DgvGrid.Rows[rowIndex].Selected = true;

            // remember the current row clicked by the user
            _currentRowIndex = rowIndex;
        }


        #endregion
    }
}
