using System;
using System.Windows.Forms;
using NorthwindWinFormViewsDynamic_CS.BusinessObject;
using NorthwindWinFormViewsDynamic_CS.Domain;

namespace NorthwindWinFormViewsDynamic_CS
{
    public partial class ListReadOnlyInvoices : Form
    {
        int _currentRecordNumber = 1;
        int _currentPageNumber = 1;
        int _totalRecords = 0;
        int _totalNumberOfPages = 0;
        int _sortColumnIndex = 0;
        string _sortByExpression = "";
        SortOrder _sortOrder = SortOrder.Ascending;
        int _currentRowIndex;
        bool _isFireToolStripComboBoxSelectedIndexChanged;

        public ListReadOnlyInvoices()
        {
            InitializeComponent();
        }

        #region winform events

        private void ListReadOnlyInvoices_Load(object sender, EventArgs e)
        {
            SetGridProperties();
            SetGridColumnProperties();
            SetDataSource(false);
            ResetNavButtonsToDefault();

        }

        #endregion

        #region binding navigator control events

        private void BnvNavMoveFirstItem_Click(object sender, EventArgs e)
        {
            _currentRecordNumber = 1;
            _currentPageNumber = 1;
            MoveToFirstPage();
        }

        private void BnvNavMovePreviousItem_Click(object sender, EventArgs e)
        {
            _currentPageNumber--;
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            MoveToPrevious();
        }

        private void BnvNavMoveNextItem_Click(object sender, EventArgs e)
        {
            _currentPageNumber++;
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            MoveToNext();
        }

        private void BnvNavMoveLastItem_Click(object sender, EventArgs e)
        {
            _currentPageNumber = _totalNumberOfPages;
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            MoveToLastPage();
        }


        #endregion

        #region data gridview events

        private void DgvGrid_ColumnHeaderMouseClick(object sender, DataGridViewCellMouseEventArgs e)
        {
            _sortColumnIndex = e.ColumnIndex;
            SetDataSource(true);
        }

        private void DgvGrid_CellContextMenuStripNeeded(object sender, DataGridViewCellContextMenuStripNeededEventArgs e)
        {
            HightlightRow(e.RowIndex);
        }

        private void DgvGrid_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            // make sure the click did not come from the header
            if (e.RowIndex != -1)
                HightlightRow(e.RowIndex);
        }

        #endregion

        #region toolstrip menu item events

        private void TscbPage_SelectedIndexChanged(object sender, EventArgs e)
        {
            // make sure this event is not called 
            // when adding items to the tool strip combo box
            if (!_isFireToolStripComboBoxSelectedIndexChanged)
                return;

            // set current page number
            int lastVisitedPageNumber = _currentPageNumber;
            _currentPageNumber = (int)TscbPage.ComboBox.SelectedItem;

            if (_currentPageNumber == 1)
                _currentRecordNumber = 1;
            else
                _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1));

            // go to the selected page
            if (_currentPageNumber == 1)
                MoveToFirstPage();
            else if (_currentPageNumber == _totalNumberOfPages)
                MoveToLastPage();
            else if (_currentPageNumber < lastVisitedPageNumber)
                MoveToPrevious();
            else
                MoveToNext();
        }

        #endregion

        #region private methods

        private void SetGridProperties()
        {
            DgvGrid.AutoGenerateColumns = false;
            DgvGrid.AllowUserToResizeRows = false;
            DgvGrid.ColumnCount = 26;
            DgvGrid.ScrollBars = ScrollBars.Horizontal;
            DgvGrid.AllowUserToOrderColumns = false;
            DgvGrid.AllowUserToAddRows = false;
            DgvGrid.AllowUserToDeleteRows = false;
            DgvGrid.ReadOnly = true;
        }

        private void SetGridColumnProperties()
        {
            DgvGrid.Columns["ShipName"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ShipAddress"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ShipCity"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ShipRegion"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ShipPostalCode"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ShipCountry"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["CustomerID"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["CustomerName"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["Address"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["City"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["Region1"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["PostalCode"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["Country"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["Salesperson"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["OrderID"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["OrderDate"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["RequiredDate"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["ShippedDate"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["ShipperName"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["ProductID"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["ProductName"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft;
            DgvGrid.Columns["UnitPrice"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["UnitPrice"].DefaultCellStyle.Format = "0.00##";
            DgvGrid.Columns["Quantity"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["Discount"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["ExtendedPrice"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["ExtendedPrice"].DefaultCellStyle.Format = "0.00##";
            DgvGrid.Columns["Freight"].DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight;
            DgvGrid.Columns["Freight"].DefaultCellStyle.Format = "0.00##";
        }

        private void MoveToFirstPage()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToFirst(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem);
        }

        private void MoveToPrevious()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToPrevious(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem, _currentRecordNumber);
        }

        private void MoveToNext()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToNext(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem, _currentPageNumber, _totalNumberOfPages);
        }

        private void MoveToLastPage()
        {
            SetDataSource(false);
            ToolStripHelper.MoveToLast(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem);
        }

        private void SetDataSource(bool isSort)
        {
            if (isSort)
                _sortByExpression = GetSortByExpression();

            // fill the datagridview
            DgvGrid.DataSource = Invoices.SelectSkipAndTake(ConstantHelper.GridNumberOfRows, _currentRecordNumber, out _totalRecords, _sortByExpression);
            DgvGrid.Columns[_sortColumnIndex].HeaderCell.SortGlyphDirection = _sortOrder;

            if (_totalRecords > 0)
            {
                _totalNumberOfPages = (int)Math.Ceiling((float)_totalRecords / (float)ConstantHelper.GridNumberOfRows);
                TscbPage.ComboBox.Items.Clear();

                // fill page numbers in toolstripcombobox
                for (int page = 1; page <= _totalNumberOfPages; page++)
                {
                    _isFireToolStripComboBoxSelectedIndexChanged = false;
                    TscbPage.ComboBox.Items.Add(page);
                }

                TscbPage.ComboBox.SelectedItem = _currentPageNumber;
                _isFireToolStripComboBoxSelectedIndexChanged = true;
            }

            ResetNavButtonsToDefault();
        }

        private string GetSortByExpression()
        {
            _sortOrder = SortOrder.Descending;

            switch (_sortColumnIndex)
            {
                case 0:
                    if (_sortByExpression == "ShipName")
                        return "ShipName desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipName";

                case 1:
                    if (_sortByExpression == "ShipAddress")
                        return "ShipAddress desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipAddress";

                case 2:
                    if (_sortByExpression == "ShipCity")
                        return "ShipCity desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipCity";

                case 3:
                    if (_sortByExpression == "ShipRegion")
                        return "ShipRegion desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipRegion";

                case 4:
                    if (_sortByExpression == "ShipPostalCode")
                        return "ShipPostalCode desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipPostalCode";

                case 5:
                    if (_sortByExpression == "ShipCountry")
                        return "ShipCountry desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipCountry";

                case 6:
                    if (_sortByExpression == "CustomerID")
                        return "CustomerID desc";

                    _sortOrder = SortOrder.Ascending;
                    return "CustomerID";

                case 7:
                    if (_sortByExpression == "CustomerName")
                        return "CustomerName desc";

                    _sortOrder = SortOrder.Ascending;
                    return "CustomerName";

                case 8:
                    if (_sortByExpression == "Address")
                        return "Address desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Address";

                case 9:
                    if (_sortByExpression == "City")
                        return "City desc";

                    _sortOrder = SortOrder.Ascending;
                    return "City";

                case 10:
                    if (_sortByExpression == "Region1")
                        return "Region1 desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Region1";

                case 11:
                    if (_sortByExpression == "PostalCode")
                        return "PostalCode desc";

                    _sortOrder = SortOrder.Ascending;
                    return "PostalCode";

                case 12:
                    if (_sortByExpression == "Country")
                        return "Country desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Country";

                case 13:
                    if (_sortByExpression == "Salesperson")
                        return "Salesperson desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Salesperson";

                case 14:
                    if (_sortByExpression == "OrderID")
                        return "OrderID desc";

                    _sortOrder = SortOrder.Ascending;
                    return "OrderID";

                case 15:
                    if (_sortByExpression == "OrderDate")
                        return "OrderDate desc";

                    _sortOrder = SortOrder.Ascending;
                    return "OrderDate";

                case 16:
                    if (_sortByExpression == "RequiredDate")
                        return "RequiredDate desc";

                    _sortOrder = SortOrder.Ascending;
                    return "RequiredDate";

                case 17:
                    if (_sortByExpression == "ShippedDate")
                        return "ShippedDate desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShippedDate";

                case 18:
                    if (_sortByExpression == "ShipperName")
                        return "ShipperName desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ShipperName";

                case 19:
                    if (_sortByExpression == "ProductID")
                        return "ProductID desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ProductID";

                case 20:
                    if (_sortByExpression == "ProductName")
                        return "ProductName desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ProductName";

                case 21:
                    if (_sortByExpression == "UnitPrice")
                        return "UnitPrice desc";

                    _sortOrder = SortOrder.Ascending;
                    return "UnitPrice";

                case 22:
                    if (_sortByExpression == "Quantity")
                        return "Quantity desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Quantity";

                case 23:
                    if (_sortByExpression == "Discount")
                        return "Discount desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Discount";

                case 24:
                    if (_sortByExpression == "ExtendedPrice")
                        return "ExtendedPrice desc";

                    _sortOrder = SortOrder.Ascending;
                    return "ExtendedPrice";

                case 25:
                    if (_sortByExpression == "Freight")
                        return "Freight desc";

                    _sortOrder = SortOrder.Ascending;
                    return "Freight";

                default:
                    if (_sortByExpression == "")
                        return " desc";

                    _sortOrder = SortOrder.Ascending;
                    return "";
            }
        }

        private void ResetNavButtonsToDefault()
        {
            BnvNavCountItem.Text = "of " + _totalNumberOfPages + " pages";

            if (_totalRecords <= ConstantHelper.GridNumberOfRows)
            {
                BnvNavMoveNextItem.Enabled = false;
                BnvNavMoveLastItem.Enabled = false;
            }
            else
            {
                BnvNavMoveNextItem.Enabled = true;
                BnvNavMoveLastItem.Enabled = true;
            }
        }

        private void HightlightRow(int rowIndex)
        {
            // highlight row
            DgvGrid.ClearSelection();
            DgvGrid.Rows[rowIndex].Selected = true;

            // remember the current row clicked by the user
            _currentRowIndex = rowIndex;
        }


        #endregion
    }
}
